import Handler from './Handler';
import { fabric } from 'fabric';
interface IFilterObject {
    type: string;
}
/**
 * 滤镜
 */
declare class FilterHandler {
    /** @ignore */
    handler: Handler;
    private filterMap;
    private filterDefault;
    /** @ignore */
    constructor(handler: Handler);
    /**
     * 通过对象设置图片滤镜
     * @param filterObject
     * @param obj
     * @returns
     */
    setFilterForObject(filterObject: IFilterObject, obj?: fabric.Object): void;
    /**
     * 设置图片滤镜，如果要设置的滤镜已经存在，则更新滤镜的值
     * @param type 设置滤镜的类型
     * @param value 滤镜的值
     * @returns
     */
    setFilter(type: string, value?: number | number[] | boolean | string): {
        version: string;
        objects: fabric.Object[];
    };
    /**
     * 删除元素所有滤镜
     * @param obj 删除滤镜的画布元素，不传入时默认画布中当前选择的元素
     * @returns
     */
    removeAllFilter(obj?: fabric.Object): void;
    /**
     * 删除元素滤镜
     * @param obj 删除滤镜的画布元素，不传入时默认画布中当前选择的元素
     * @returns
     */
    removeFilter(type: string, obj?: fabric.Object): {
        version: string;
        objects: fabric.Object[];
    };
    /**
     * 获取对象滤镜的值
     * @param type 滤镜类型
     * @param obj 画布元素，不传入时默认画布中当前选择的元素
     * @returns 对应滤镜类型的值
     */
    getFilterValue(type: string, obj?: fabric.Object): string | number | boolean;
    /**
     * 对应滤镜的默认值，如果用户设置的值为默认值，那么删除元素的滤镜
     */
    private filterDefaultValue;
    /**
     * 初始化灰度滤镜
     * @returns 灰度滤镜
     */
    private initGrayscale;
    /**
     * 初始化反转滤镜
     * @returns 反转滤镜
     */
    private initInvert;
    /**
     * 初始化棕褐滤镜
     * @returns 棕褐滤镜
     */
    private initSepia;
    /**
     * 初始化亮度滤镜
     * @returns 亮度滤镜
     */
    private initBrightness;
    /**
     * 初始化对比度滤镜
     * @returns 对比度滤镜
     */
    private initContrast;
    /**
     * 初始化饱和度滤镜
     * @returns 饱和度滤镜
     */
    private initSaturation;
    /**
     * 初始化噪音滤镜
     * @returns 噪音滤镜
     */
    private initNoise;
    /**
     * 初始化像素滤镜
     * @returns 像素滤镜
     */
    private initPixelate;
    /**
     * 初始化模糊滤镜
     * @returns 模糊滤镜
     */
    private initBlur;
    /**
     * 初始化锐化滤镜
     * @returns 锐化滤镜
     */
    private initSharpen;
    /**
     * 初始化浮雕滤镜
     * @returns 浮雕滤镜
     */
    private initEmboss;
    /**
     * 初始化色彩滤镜
     * @returns 色彩滤镜
     */
    private initTechnicolor;
    /**
     * 初始化gama滤镜
     * @returns gama滤镜
     */
    private initGamma;
    /**
     * 初始化宝丽来滤镜
     * @returns 宝丽来滤镜
     */
    private initPolaroid;
    /**
     * 初始化柯达滤镜
     * @returns 柯达滤镜
     */
    private initKodachrome;
    /**
     * 初始化黑白滤镜
     * @returns 黑白滤镜
     */
    private initBlackWhite;
    /**
     * 初始化色调滤镜
     * @returns 色调滤镜
     */
    private initHueRotation;
}
export default FilterHandler;
