import Handler from './Handler';
import { IJsonData } from '../interface';
/**
 * 画布渲染的处理器
 */
declare class RenderHandler {
    /** @ignore */
    handler: Handler;
    /** @ignore */
    constructor(handler: Handler);
    /**
     * 渲染JSON到画布
     * @param json - 需要渲染的JSON
     */
    loadJson(json: IJsonData, callback?: () => void): void;
    /**
     * 如果json中存在大于阀值的图片，fabric本身的loadFromJSON加载以后
     * 会对图片做特殊的renderAni处理，导致画布卡顿
     * 目前的解决方式是删除这张图片，然后手动加载
     * @param json json数组
     */
    private reloadImg;
    /**
     * 重新设置画布中的元素
     * @param json 画布渲染json
     */
    private resetCanvasObjs;
    /**
     * 添加图片到画布
     * @param url - 需要渲染的图片url
     * @param type - 图片类型
     */
    uploadImg(url: string, type: string): void;
    /**
     * 设置所有渲染的图片 crossOrigin:Anonymous
     */
    private resetCrossOrigin;
    /**
     * 为json添加默认的workarea元素
     * @param objects 所有的子元素
     */
    private addWorkarea;
}
export default RenderHandler;
