/// <reference types="plugin-typings" />
import ConverterCommon from './ConverterCommon';
import { IInitFabricObj } from '../../interface';
interface ICanvasNode {
    type: string;
    id: string;
    children: TextNode[];
    visible: boolean;
}
type IAllLayer = ICanvasNode | TextNode | PageNode | SceneNode;
declare class Converter {
    converterCommon: ConverterCommon;
    imgList: {
        [key: string]: string;
    };
    fileId: string;
    token: string;
    constructor(images: {
        [key: string]: string;
    }, fileId: string, token: string);
    /**
     * 分发解析的层
     * @param layer 解析层
     * @returns 结果
     */
    parseLayerAsync(layer: IAllLayer): Promise<IInitFabricObj>;
    /**
     * 解析画布层
     * @param layer 画布层
     * @returns 解析后的结果
     */
    private converterCanvasAsync;
    /**
     * 解析文字层
     * @param layer 文字层
     * @returns 解析后的结果
     */
    private converterText;
    /**
     * 解析矩形
     * @param layer 矩形层
     * @returns 解析后的结果
     */
    private converterRectAsync;
    /**
     * 转换frame
     * @param layer frame层
     * @returns 转换结果
     */
    private converterFrameAsync;
    /**
     * 转换group
     * @param layer group层
     * @returns 转换结果
     */
    private converterGroupAsync;
    /**
     * 兜底的解析方案，解析为图片
     * @param layer 需要解析的图层
     * @returns 解析结果
     */
    private converterCommonNodeAsync;
    /**
     * 转换flexbox
     * @param groupObj 层
     */
    private converterFlexBoxAsync;
    private resetGroup;
}
export default Converter;
